Summary:   A fast, lightweight distributed source control management system
Name:      mercurial
Version:   1.1.2
Release:   %mkrel 1
License:   GPLv2
Group:     Development/Other
URL: 	   http://www.selenic.com/mercurial/
Source0:   http://www.selenic.com/mercurial/release/%{name}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: python-devel
BuildRequires: xmlto
BuildRequires: asciidoc
Provides: hg = %{version}-%{release}

%description
Mercurial is a fast, lightweight source control management system
designed for efficient handling of very large distributed
projects. Features include:

  * O(1) delta-compressed file storage and retrieval scheme
  * Complete cross-indexing of file and changesets for efficient exploration
    of project history
  * Robust SHA1-based integrity checking and append-only storage model
  * Decentralized development model with arbitrary merging between trees
  * High-speed HTTP-based network merge protocol
  * Easy-to-use command-line interface
  * Integrated stand-alone web interface
  * Small Python codebase

%prep
%setup -q

%build
make all

%install
rm -rf $RPM_BUILD_ROOT
python setup.py install -O1 --root $RPM_BUILD_ROOT --prefix %{_prefix} --record=%{name}.files
make install-doc DESTDIR=$RPM_BUILD_ROOT MANDIR=%{_mandir}

install contrib/hgk          $RPM_BUILD_ROOT%{_bindir}
install contrib/convert-repo $RPM_BUILD_ROOT%{_bindir}/mercurial-convert-repo
install contrib/hg-ssh       $RPM_BUILD_ROOT%{_bindir}
install contrib/git-viz/{hg-viz,git-rev-tree} $RPM_BUILD_ROOT%{_bindir}

bash_completion_dir=$RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d
mkdir -p $bash_completion_dir
install -m 644 contrib/bash_completion $bash_completion_dir/mercurial.sh

zsh_completion_dir=$RPM_BUILD_ROOT%{_datadir}/zsh/site-functions
mkdir -p $zsh_completion_dir
install -m 644 contrib/zsh_completion $zsh_completion_dir/_mercurial

lisp_dir=$RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp
mkdir -p $lisp_dir
install -m 644 contrib/mercurial.el $lisp_dir
xlisp_dir=$RPM_BUILD_ROOT%{_datadir}/xemacs/site-packages/lisp
mkdir -p $xlisp_dir
install -m 644 contrib/mercurial.el $xlisp_dir
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/mercurial/hgrc.d

%clean
rm -rf $RPM_BUILD_ROOT

%files -f %{name}.files
%defattr(-,root,root,-)
%doc CONTRIBUTORS COPYING doc/README doc/hg*.txt doc/hg*.html doc/ja *.cgi
%dir %{_sysconfdir}/mercurial
%dir %{_sysconfdir}/mercurial/hgrc.d
%_mandir/man*/*
%{_sysconfdir}/bash_completion.d/mercurial.sh
%{_datadir}/zsh/site-functions/_mercurial
%{_datadir}/emacs/site-lisp/mercurial.el
%{_datadir}/xemacs/site-packages/lisp/mercurial.el
%{_bindir}/hgk
%{_bindir}/hg-ssh
%{_bindir}/hg-viz
%{_bindir}/git-rev-tree
%{_bindir}/mercurial-convert-repo


%changelog
* Sat Jan 03 2009 Jérôme Soyer <saispo@mandriva.org> 1.1.2-1mdv2009.1
+ Revision: 323882
- New upstream release

* Thu Dec 25 2008 Michael Scherer <misc@mandriva.org> 1.1-2mdv2009.1
+ Revision: 318497
- rebuild for new python

* Sat Dec 20 2008 Olivier Thauvin <nanardon@mandriva.org> 1.1-1mdv2009.1
+ Revision: 316544
- 1.1

* Fri Aug 15 2008 Lev Givon <lev@mandriva.org> 1.0.2-1mdv2009.0
+ Revision: 272385
- Update to 1.0.2.

* Fri Aug 08 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.0.1-2mdv2009.0
+ Revision: 268141
- rebuild early 2009.0 package (before pixel changes)

* Sun Jun 01 2008 Lev Givon <lev@mandriva.org> 1.0.1-1mdv2009.0
+ Revision: 214142
- Update to 1.0.1.

* Sun Apr 13 2008 Lev Givon <lev@mandriva.org> 1.0-1mdv2009.0
+ Revision: 192649
- Update to 1.0.

* Sat Mar 01 2008 Nicolas Lécureuil <neoclust@mandriva.org> 0.9.5-2mdv2008.1
+ Revision: 177399
- Fix group
- Sync spec file with fedora
  Add cgi files (Bug #36194)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Nov 09 2007 Jérôme Soyer <saispo@mandriva.org> 0.9.5-1mdv2008.1
+ Revision: 107084
- New release

* Tue Jul 17 2007 Jérôme Soyer <saispo@mandriva.org> 0.9.4-1mdv2008.0
+ Revision: 53115
- New release


* Tue Dec 19 2006 Gaëtan Lehmann <glehmann@mandriva.org> 0.9.3-1mdv2007.0
+ Revision: 100353
- 0.9.3

* Mon Dec 18 2006 Gaëtan Lehmann <glehmann@mandriva.org> 0.9.2-2mdv2007.1
+ Revision: 98735
- bump release
- 0.9.2

* Wed Dec 06 2006 Thierry Vignaud <tvignaud@mandriva.com> 0.9-2mdv2007.1
+ Revision: 91457
- rebuild with new python

  + Nicolas Lécureuil <neoclust@mandriva.org>
    - import mercurial-0.9-1mdk

* Sat May 13 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 0.9-1mdk
- New release 0.9

* Wed Feb 01 2006 Gaetan Lehmann <glehmann@deborah.mandriva.com> 0.8-2mdk
- fix build on x86_64 (drop patch0)

* Tue Jan 31 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 0.8-1mdk
- New release 0.8

* Fri Oct 21 2005 Nicolas Lcureuil <neoclust@mandriva.org> 0.7-2mdk
- Fix BuildRequires

* Wed Oct 05 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 0.7-1mdk
- New release 0.7

* Fri Sep 09 2005 Gaetan Lehmann <glehmann@mandrakesoft.com> 0.6c-1mdk
- New release 0.6c
- generate doc with asciidoc
- make tests
- patch0: better detection of lib name to allow tests to run on 32 bits
  system with a /usr/lib64 directory (like n4 on mandriva cluster)

* Fri Jun 03 2005 Frederic Lepied <flepied@mandriva.com> 0.5b-1mdk
- initial package

